@@ -15,6 +15,7 @@ class DummyExtension(object):
 if PLATFORM in ('darwin', 'linux2', 'linux'):
     hook_installed = False
     original_os_fork = os.fork
+    _fork = None
 
     if CPYTHON:
         try:
@@ -27,6 +28,7 @@ if PLATFORM in ('darwin', 'linux2', 'linux'):
     native_extensions.python_fork_handler_called = 1
 
     def os_fork_hook():
+        global _fork
         try:
             from .singleton import singleton_obj
 
@@ -58,6 +60,10 @@ if PLATFORM in ('darwin', 'linux2', 'linux'):
 
                 # restore original fork
                 os.fork = original_os_fork
+
+                # At this point the rook is fully down
+                if _fork:
+                    interface.start()
             else:
                 # parent
                 singleton_obj.post_fork_recover()
@@ -69,8 +75,8 @@ if PLATFORM in ('darwin', 'linux2', 'linux'):
 
         return pid
 
-    def install_fork_handler():
-        global hook_installed, original_os_fork
+    def install_fork_handler(fork):
+        global hook_installed, original_os_fork, _fork
 
         if hook_installed:
             return
@@ -80,7 +86,7 @@ if PLATFORM in ('darwin', 'linux2', 'linux'):
             # functionality is disabled
             native_extensions.RegisterPreforkCallback()
 
-        os.fork, hook_installed = os_fork_hook, True
+        os.fork, hook_installed, _fork = os_fork_hook, True, fork
 
     def remove_fork_handler():
         global hook_installed, original_os_fork
@@ -88,5 +94,5 @@ if PLATFORM in ('darwin', 'linux2', 'linux'):
         os.fork, hook_installed = original_os_fork, False
 
 else:
-    def install_fork_handler():
+    def install_fork_handler(fork):
         pass
