@@ -9,6 +9,7 @@ from rook.processor.namespaces.container_namespace import ContainerNamespace
 from rook.processor.namespaces.stack_namespace import StackNamespace
 from rook.processor.namespaces.python_utils_namespace import PythonUtilsNamespace
 from rook.processor.namespaces.trace_namespace import TraceNamespace
+from rook.processor.namespaces.noop_namespace import NoopNamespace
 from rook.exceptions import RookRuleMaxExecutionTimeReached, RookRuleRateLimited
 from rook.augs.aug_rate_limiter import AugRateLimiter
 
@@ -77,6 +78,7 @@ class Aug(object):
                     'python': PythonUtilsNamespace(),
                     'utils': PythonUtilsNamespace(),
                     'trace': TraceNamespace(),
+                    'state': NoopNamespace()
                 })
 
                 if not self._condition or self._condition.evaluate(namespace, extracted):
