@@ -13,7 +13,10 @@ from rook.logger import logger
 
 
 class Information(object):
-    def collect(self):
+    def __init__(self):
+        self.debug = False
+
+    def collect(self, debug=False):
         for name, collector in six.iteritems(self._collectors):
             try:
                 if callable(collector):
@@ -27,6 +30,8 @@ class Information(object):
                 setattr(self, name, "")
                 pass
 
+        self.debug = debug
+
         return self
 
 
@@ -138,8 +143,8 @@ class AgentInformation(Information):
         }
 
 
-def collect():
-    return AgentInformation().collect()
+def collect(debug):
+    return AgentInformation().collect(debug)
 
 
 def pack_agent_info(info):
@@ -178,6 +183,9 @@ def pack_agent_info(info):
     for label_key, label_value in six.iteritems(info.labels):
         packed_info.labels[label_key] = label_value
 
+    if info.debug:
+        packed_info.labels["rookout_debug"] = "on"
+
     packed_info.tags.extend(info.tags)
 
     return packed_info
