@@ -29,7 +29,7 @@ class ControllerAddress(object):
 
 class AgentComConfiguration(object):
     COMMAND_THREAD_NAME = "rookout_agent_com"
-    MAX_MESSAGE_LENGTH = 100 * 1024 * 1024
+    MAX_MESSAGE_LENGTH = 1024 * 1024
     BACK_OFF = 0.2
     MAX_SLEEP = 60
     TIMEOUT = 3
