@@ -44,16 +44,16 @@ class WebHookRetryLevelException(Exception):
     def __init__(self, retry_level, valid_levels):
         super(WebHookRetryLevelException, self).__init__("Invalid retry level for webhook %s" % retry_level,
                                                          {
-                                                        "retry_level": retry_level,
-                                                        "valid_levels": valid_levels}
+                                                             "retry_level": retry_level,
+                                                             "valid_levels": valid_levels}
                                                          )
 
 
 class RookInvalidArithmeticPath(RookInputException):
     def __init__(self, configuration, error=None):
-        super(RookInvalidArithmeticPath, self).__init__("Invalid arithmetic path configuration. configuration: %s, innerException: %s" % (configuration, error),
-                                                        {'configuration': configuration, 'error': error})
-
+        super(RookInvalidArithmeticPath, self).__init__(
+            "Invalid arithmetic path configuration. configuration: %s, innerException: %s" % (configuration, error),
+            {'configuration': configuration, 'error': error})
 
 
 class RookAugInvalidKey(RookInputException):
@@ -65,7 +65,8 @@ class RookAugInvalidKey(RookInputException):
 
 class RookObjectNameMissing(RookInputException):
     def __init__(self, configuration):
-        super(RookObjectNameMissing, self).__init__("Failed to find object name %s" % configuration, {'configuration': configuration})
+        super(RookObjectNameMissing, self).__init__("Failed to find object name %s" % configuration,
+                                                    {'configuration': configuration})
 
 
 class RookUnknownObject(RookInputException):
@@ -91,33 +92,37 @@ class RookMonitorException(RookException):
 
 class RookHashFailedException(RookMonitorException):
     def __init__(self, module_name):
-        super(RookHashFailedException, self).__init__("Failed to calculate hash %s" % module_name, {'module': module_name})
+        super(RookHashFailedException, self).__init__("Failed to calculate hash %s" % module_name,
+                                                      {'module': module_name})
 
 
 class RookHashMismatchException(RookMonitorException):
     def __init__(self, filepath, expected, calculated, gitBlob=None):
-        super(RookHashMismatchException, self).__init__("File hashes do not match! path: %s, expected: %s, calculated: %s" % (filepath, expected, calculated),
-                                                        {'filepath': filepath,
-                                                         'expected': expected,
-                                                         'calculated': calculated,
-                                                         'gitBlob': gitBlob})
+        super(RookHashMismatchException, self).__init__(
+            "File hashes do not match! path: %s, expected: %s, calculated: %s" % (filepath, expected, calculated),
+            {'filepath': filepath,
+             'expected': expected,
+             'calculated': calculated,
+             'gitBlob': gitBlob})
 
 
 class RookCrcMismatchException(RookMonitorException):
     def __init__(self, filepath, expected, calculated, gitBlob=None):
-        super(RookCrcMismatchException, self).__init__("Line CRC32s do not match! path: %s, expected: %s, calculated: %s" % (filepath, expected, calculated),
-                                                        {'filepath': filepath,
-                                                         'expected': expected,
-                                                         'calculated': calculated,
-                                                         'gitBlob': gitBlob})
+        super(RookCrcMismatchException, self).__init__(
+            "Line CRC32s do not match! path: %s, expected: %s, calculated: %s" % (filepath, expected, calculated),
+            {'filepath': filepath,
+             'expected': expected,
+             'calculated': calculated,
+             'gitBlob': gitBlob})
 
 
 class RookLineMoved(RookMonitorException):
     def __init__(self, filepath, old_line_no, new_line_no):
-        super(RookLineMoved, self).__init__("Line has moved! path: %s, original line no: %s, new line no: %s" % (filepath, old_line_no, new_line_no),
-                                                        {'filepath': filepath,
-                                                         'old_line_no': old_line_no,
-                                                         'new_line_no': new_line_no})
+        super(RookLineMoved, self).__init__(
+            "Line has moved! path: %s, original line no: %s, new line no: %s" % (filepath, old_line_no, new_line_no),
+            {'filepath': filepath,
+             'old_line_no': old_line_no,
+             'new_line_no': new_line_no})
 
 
 class RookHashCalculationFailed(RookMonitorException):
@@ -172,15 +177,16 @@ class RookMethodNotFound(RookMonitorException):
 class RookInvalidMethodArguments(RookMonitorException):
     def __init__(self, method, args):
         super(RookInvalidMethodArguments, self).__init__("Bad method arguments: method: %s, args %s" % (method, args),
-                                                 {'method': method,
-                                                  'arguments': args})
+                                                         {'method': method,
+                                                          'arguments': args})
 
 
 class RookWriteAttributeNotSupported(RookMonitorException):
     def __init__(self, namespace_type, attribute):
-        super(RookWriteAttributeNotSupported, self).__init__("Namespace %s does not support write" % namespace_type.__name__,
-                                                             {'namespace': namespace_type.__name__,
-                                                              'attribute': attribute})
+        super(RookWriteAttributeNotSupported, self).__init__(
+            "Namespace %s does not support write" % namespace_type.__name__,
+            {'namespace': namespace_type.__name__,
+             'attribute': attribute})
 
 
 class RookOperationReadOnly(RookMonitorException):
@@ -197,7 +203,8 @@ class RookRuleRateLimited(RookException):
 
 class RookRuleMaxExecutionTimeReached(RookException):
     def __init__(self):
-        super(RookRuleMaxExecutionTimeReached, self).__init__("Breakpoint was disabled because it has reached its maximum execution time")
+        super(RookRuleMaxExecutionTimeReached, self).__init__(
+            "Breakpoint was disabled because it has reached its maximum execution time")
 
 
 class RookNoHttpServiceRegistered(RookException):
@@ -283,25 +290,34 @@ class RookSourceFileNotFound(RookInputException):
 
 class RookDependencyError(RookException):
     def __init__(self, exc):
-        super(RookDependencyError, self).__init__("%s, Make sure to run 'pip install rook' on the same platform/architecture. "
-                                                  "For more information: https://docs.rookout.com/docs/sdk-setup.html#building-1" % exc,
-                                                        {'throwable': exc})
+        super(RookDependencyError, self).__init__(
+            "%s, Make sure to run 'pip install rook' on the same platform/architecture. "
+            "For more information: https://docs.rookout.com/docs/sdk-setup.html#building-1" % exc,
+            {'throwable': exc})
 
 
 class RookDependencyMissing(RookException):
     def __init__(self, dep, exc=None):
-        super(RookDependencyMissing, self).__init__("missing dependency %s" % dep,{ 'throwable': exc, 'dep': dep })
+        super(RookDependencyMissing, self).__init__("missing dependency %s" % dep, {'throwable': exc, 'dep': dep})
 
 
 class RookDependencyConflict(RookException):
     def __init__(self, dep):
         super(RookDependencyConflict, self).__init__("Rookout does not support running with %s installed" % dep,
-                                                    {'dep': dep})
+                                                     {'dep': dep})
 
 
 class RookSourceFilePathSuggestion(RookException):
     def __init__(self, wanted_path, matching_path):
         super(RookSourceFilePathSuggestion, self).__init__("Rookout found alternative file path: %s" % matching_path,
-                                                    {'wanted_path': wanted_path,
-                                                     'matching_path': matching_path})
+                                                           {'wanted_path': wanted_path,
+                                                            'matching_path': matching_path})
 
+
+class RookMessageSizeExceeded(RookException):
+    def __init__(self, message_size, max_message_size):
+        super(RookMessageSizeExceeded, self).__init__("Message size of %d exceeds max size limit of %d. "
+                                                      "Consider changing the depth of collection and trying again." %
+                                                      (message_size, max_message_size),
+                                                      {'message_size': message_size,
+                                                       'max_message_size': max_message_size})
