@@ -9,6 +9,7 @@ import six
 from rook.config import ImportServiceConfig
 from rook.serverless import on_lambda
 
+
 _rook = None
 _debug = False
 _throw_errors = False
@@ -170,7 +171,7 @@ def start(token=None,
             import rook.singleton
             _rook = rook.singleton.singleton_obj
 
-            return _rook.connect(token, host, port, proxy, tags, labels, async_start, _fork)
+            return _rook.connect(token, host, port, proxy, tags, labels, async_start, _fork, _debug)
         except (RookMissingToken, RookInvalidToken, RookVersionNotSupported, RookOldServers) as e:
             if not _throw_errors:
                 six.print_("[Rookout] Failed to start Rookout:", e, file=sys.stderr)
@@ -195,6 +196,12 @@ def start(token=None,
             traceback.print_exc()
 
 
+def capture_exception(exc):
+    from rook.collect import exception_collect
+
+    exception_collect(exc)
+
+
 def flush():
     global _rook
     if _rook is None:
