@@ -20,7 +20,6 @@ from .namespaces.string_namespace import StringNamespace
 from .namespaces.unknown_namespace import UnknownNamespace
 from .namespaces.code_object_namespace import CodeObjectNamespace
 from .namespaces.dynamic_object_namespace import DynamicObjectNamespace
-from .namespaces.delayed_namespace import DelayedNamespace
 
 from ..logger import logger
 
@@ -77,8 +76,6 @@ class NamespaceSerializer(object):
                 return self.dump_code_namespace(namespace, variant, log_errors)
             elif isinstance(namespace, DynamicObjectNamespace):
                 return self.dump_dynamic_namespace(namespace, variant, log_errors)
-            elif isinstance(namespace, DelayedNamespace):
-                return self.dump_delayed_namespace(namespace, variant, log_errors)
             else:
                 raise NotImplementedError("Does not support serializing this type!", type(namespace))
         except Exception as e:
@@ -152,33 +149,29 @@ class NamespaceSerializer(object):
                 logger.exception(message)
 
     def _dump_python_object_unsafe(self, obj, variant, current_depth, config, log_errors):
-        if current_depth == config.max_depth:
-            self._dump_max_depth(obj, variant)
+        self._dump_base_object(obj, variant, current_depth, config, log_errors)
+        if self._is_primitive(obj):
+            self._dump_primitive(obj, str(type(obj)), variant, config.max_string)
+        elif isinstance(obj, LIST_TYPE):
+            self._dump_list(obj, variant, current_depth, config, log_errors)
+        elif isinstance(obj, dict):
+            self._dump_dictionary(obj, variant, current_depth, config, log_errors)
+        elif isinstance(obj, BaseException):
+            self._dump_exception(obj, variant, current_depth, config, log_errors)
+        elif isinstance(obj, TracebackType):
+            self._dump_traceback(obj, variant, current_depth, config, log_errors)
+        elif NamespaceSerializer.is_numpy_obj(obj):
+            self._dump_primitive(obj.item(), str(type(obj)), variant, config.max_string)
+        elif NamespaceSerializer.is_torch_obj(obj):
+            self._dump_primitive(str(obj), str(type(obj)), variant, config.max_string)
+        elif NamespaceSerializer.is_multidict_obj(obj):
+            self._dump_primitive(str(obj), str(type(obj)), variant, config.max_string)
+        elif NamespaceSerializer.is_protobuf_obj(obj):
+            self._dump_protobuf(obj, variant, current_depth, config, log_errors)
+        elif hasattr(obj, '__dict__'):
+            self._dump_user_class(obj, variant, current_depth, config)
         else:
-            self._dump_base_object(obj, variant, current_depth, config, log_errors)
-
-            if self._is_primitive(obj):
-                self._dump_primitive(obj, str(type(obj)), variant, config.max_string)
-            elif isinstance(obj, LIST_TYPE):
-                self._dump_list(obj, variant, current_depth, config, log_errors)
-            elif isinstance(obj, dict):
-                self._dump_dictionary(obj, variant, current_depth, config, log_errors)
-            elif isinstance(obj, BaseException):
-                self._dump_exception(obj, variant, current_depth, config, log_errors)
-            elif isinstance(obj, TracebackType):
-                self._dump_traceback(obj, variant, current_depth, config, log_errors)
-            elif NamespaceSerializer.is_numpy_obj(obj):
-                self._dump_primitive(obj.item(), str(type(obj)), variant, config.max_string)
-            elif NamespaceSerializer.is_torch_obj(obj):
-                self._dump_primitive(str(obj), str(type(obj)), variant, config.max_string)
-            elif NamespaceSerializer.is_multidict_obj(obj):
-                self._dump_primitive(str(obj), str(type(obj)), variant, config.max_string)
-            elif NamespaceSerializer.is_protobuf_obj(obj):
-                self._dump_protobuf(obj, variant, current_depth, config, log_errors)
-            elif hasattr(obj, '__dict__'):
-                self._dump_user_class(obj, variant, current_depth, config)
-            else:
-                self._dump_not_supported(obj, variant)
+            self._dump_not_supported(obj, variant)
 
         # If debugging NamespaceSerializer
         if ProtobufConfiguration.NAMESPACE_SERIALIZER_DUMPING:
@@ -212,9 +205,24 @@ class NamespaceSerializer(object):
         variant.string_value.original_size = len(value)
         variant.string_value.value = value
 
+    def _get_object_width(self, obj):
+        object_width = 0
+        if hasattr(obj, '__dict__') and obj.__dict__:
+            object_width += len(obj.__dict__)
+        if hasattr(obj, '__slots__') and obj.__slots__:
+            object_width += len(obj.__slots__)
+        return object_width
+
     def _dump_base_object(self, obj, variant, current_depth, config, log_errors):
         variant.original_type = str(type(obj))
 
+        object_width = self._get_object_width(obj)
+        object_weight = current_depth + (2 if object_width >= config.max_width else 1)
+        if object_weight >= config.max_depth:
+            if object_width:
+                self._set_max_depth_flag(variant)
+            return
+
         if hasattr(obj, '__dict__'):
             # __dict is copied before iteration, as it might
             # change in another thread. We do not deep copy,
@@ -224,7 +232,7 @@ class NamespaceSerializer(object):
                 if key not in self.BUILTIN_ATTRIBUTES_IGNORE:
                     attribute = variant.attributes.add()
                     attribute.name = key
-                    self._dump_python_object(value, attribute.value, current_depth+1, config, log_errors)
+                    self._dump_python_object(value, attribute.value, object_weight, config, log_errors)
 
         if hasattr(obj, '__slots__') and obj.__slots__:
             items = obj.__slots__
@@ -240,7 +248,7 @@ class NamespaceSerializer(object):
                         value = getattr(obj, key)
                     except AttributeError:
                         value = None
-                    self._dump_python_object(value, attribute.value, current_depth + 1, config, log_errors)
+                    self._dump_python_object(value, attribute.value, object_weight, config, log_errors)
 
     try:
         BINARY_TYPES = (buffer, bytearray)
@@ -256,9 +264,12 @@ class NamespaceSerializer(object):
     def _is_primitive(obj):
         return isinstance(obj, NamespaceSerializer.PRIMITIVE_TYPES)
 
-    def _dump_max_depth(self, namespace, variant):
+    def _dump_max_depth(self, variant):
         variant.variant_type = variant.VARIANT_MAX_DEPTH
 
+    def _set_max_depth_flag(self, variant):
+        variant.max_depth = True
+
     def _dump_primitive(self, obj, original_type, variant, max_string):
         if obj is None:
             variant.variant_type = variant.VARIANT_NONE
@@ -456,9 +467,6 @@ class NamespaceSerializer(object):
     def dump_dynamic_namespace(self, namespace, variant, log_errors):
         variant.variant_type = variant.VARIANT_DYNAMIC
 
-    def dump_delayed_namespace(self, namespace, variant, log_errors):
-        variant.MergeFrom(namespace.get_variant())
-
     def dump_type_namespace(self, namespace, variant, log_errors):
         self._dump_dumped_object_namespace(namespace, variant, log_errors)
 
