@@ -19,17 +19,5 @@ class DumpedPrimitiveNamespace(DumpedObjectNamespace):
         else:
             return self.obj
 
-    def to_dict(self):
-        return {
-            u'@namespace': self.__class__.__name__,
-            u'@common_type': self.common_type,
-            u'@original_type': self.type,
-            u'@attributes' : self.get_attributes_dict(),
-            u'@value': self._get_value_for_json(),
-            }
-
-    def to_simple_dict(self):
-        return self._get_value_for_json()
-
     def __hash__(self):
         return hash(self.obj)
