@@ -2,7 +2,7 @@ import six
 from ...logger import logger
 
 from rook.processor.paths.arithmetic_path_internal import parse, ParseError
-from rook.exceptions import RookInvalidArithmeticPath, RookNonPrimitiveObjectType, RookAttributeNotFound, RookOperationReadOnly, RookExceptionEvaluationFailed
+from rook.exceptions import RookInvalidArithmeticPath, RookNonPrimitiveObjectType, RookAttributeNotFound, RookOperationReadOnly, RookExceptionEvaluationFailed, ToolException
 from ..namespaces.python_object_namespace import PythonObjectNamespace
 from ..namespaces.container_namespace import ContainerNamespace
 
@@ -91,7 +91,7 @@ class LookupOperation(Marker):
         raise RookOperationReadOnly(type(self))
 
 
-class ToolException(Marker):
+class ToolException_(Marker):
     def __init__(self, exc):
         self.obj = exc
 
@@ -352,7 +352,7 @@ class Actions(object):
 
         function_name = elements[0].text + elements[1].text
 
-        if isinstance(elements[3], ToolException):
+        if isinstance(elements[3], ToolException_):
             return elements[3]
 
         args = elements[3].text
@@ -367,7 +367,7 @@ class Actions(object):
 
         function_name = elements[1].text + elements[2].text
 
-        if isinstance(elements[4], ToolException):
+        if isinstance(elements[4], ToolException_):
             return elements[4]
 
         args = elements[4].text
@@ -396,7 +396,7 @@ class Actions(object):
 
             # Check if we have some exceptions in the operations chain - might happen if function parsing failed.
             for op in self.operations:
-                if isinstance(op, ToolException):
+                if isinstance(op, ToolException_):
                     return op
 
             result = elements[1].read(self.namespace, False)
@@ -410,7 +410,7 @@ class Actions(object):
 
             return NamespaceResult(result)
         except Exception as e:
-            return ToolException(e)
+            return ToolException_(e)
 
     @staticmethod
     def make_comp_exp_ex(input, start, end, elements):
@@ -434,14 +434,14 @@ class Actions(object):
         if len(elements[1].elements) == 0:
             return elements[0]
 
-        if isinstance(elements[0], ToolException):
+        if isinstance(elements[0], ToolException_):
             return elements[0]
 
         flat_elements = [elements[0]]
         for n in elements[1].elements:
             flat_elements.append(n.elements[0])
 
-            if isinstance(n.elements[1], ToolException):
+            if isinstance(n.elements[1], ToolException_):
                 return n.elements[1]
             flat_elements.append(n.elements[1])
 
@@ -524,11 +524,16 @@ class ArithmeticPath(object):
     NAME = 'calc'
 
     def __init__(self, configuration, factory=None):
+        self.negation = False
         if isinstance(configuration, six.string_types):
             string = configuration
         else:
             string = configuration['path']
 
+        if string.startswith("NOT(") and string.endswith(")"):
+            string = string[len("NOT("):len(string)-1]
+            self.negation = True
+
         self.expression = string
         if self.expression == "":
             raise RookInvalidArithmeticPath(self.expression)
@@ -540,7 +545,7 @@ class ArithmeticPath(object):
             result = parse(self.expression, actions=context)
         except ParseError as e:
             raise RookInvalidArithmeticPath(self.expression, e)
-        return self.normalize_result(result)
+        return self.normalize_result(result, self.expression)
 
     def write_to(self, root_namespace, value):
         context = Actions(root_namespace)
@@ -564,8 +569,7 @@ class ArithmeticPath(object):
 
         context.operations[i].write(namespace, value)
 
-    @staticmethod
-    def normalize_result(result):
+    def normalize_result(self, result, expression):
         if isinstance(result, Array):
             new_arr = []
             for e in result.obj:
@@ -575,10 +579,17 @@ class ArithmeticPath(object):
         if isinstance(result, NamespaceResult):
             return result.obj
 
-        if isinstance(result, ToolException):
-            raise result.obj
+        if isinstance(result, ToolException_):
+            if isinstance(result.obj, ToolException):
+                raise result.obj
+            else:
+                raise RookInvalidArithmeticPath(expression, result.obj)
 
         if isinstance(result, NonPrimitiveNamespaceResult):
             raise result.obj
 
-        return PythonObjectNamespace(result.obj)
+        res = result.obj
+        if isinstance(res, bool) and self.negation:
+            res = not res
+
+        return PythonObjectNamespace(res)
