@@ -226,19 +226,24 @@ def _FindCodeObjectsReferents(module, start_objects, visit_recorder):
         continue
 
       for obj in referents:
-        if isinstance(obj, _BFS_IGNORE_TYPES) or not visit_recorder.Record(obj):
-          continue
+        try:
+          if isinstance(obj, _BFS_IGNORE_TYPES) or not visit_recorder.Record(obj):
+            continue
 
-        if isinstance(obj, types.CodeType) and CheckIgnoreCodeObject(obj):
-          continue
+          if isinstance(obj, types.CodeType) and CheckIgnoreCodeObject(obj):
+            continue
 
-        if isinstance(obj, six.class_types) and CheckIgnoreClass(obj):
-          continue
+          if isinstance(obj, six.class_types) and CheckIgnoreClass(obj):
+            continue
 
-        if isinstance(obj, types.CodeType):
-          code_objects.add(obj)
-        else:
-          new_current.append(obj)
+          if isinstance(obj, types.CodeType):
+            code_objects.add(obj)
+          else:
+            new_current.append(obj)
+
+        # As we are using weak references to iterate, they can disappear
+        except ReferenceError:
+          pass
 
     current = new_current
     depth += 1
@@ -271,7 +276,12 @@ class _VisitRecorder(object):
     if len(self._visit_recorder_objects) >= _MAX_VISIT_OBJECTS:
       return False
 
-    obj_id = id(obj)
+    # id may potentially invoke end user code, so we protect it with a try/except
+    try:
+      obj_id = id(obj)
+    except:
+      return False
+
     if obj_id in self._visit_recorder_objects:
       return False
 
