@@ -80,7 +80,7 @@ class _Singleton(object):
     def get_trigger_services(self):
         return self._trigger_services
 
-    def connect(self, token, host, port, proxy, tags=None, labels=None, async_start=False, fork=False):
+    def connect(self, token, host, port, proxy, tags=None, labels=None, async_start=False, fork=False, debug=False):
         """Connect to the Agent."""
         if self._agent_com:
             raise RookInterfaceException("Multiple connection attempts not supported!")
@@ -94,7 +94,7 @@ class _Singleton(object):
         tags = tags or []
 
         self._start_trigger_services()
-        self._agent_com = AgentCom(self._id, host, port, proxy, token, labels, tags)
+        self._agent_com = AgentCom(self._id, host, port, proxy, token, labels, tags, debug)
         self._command_handler = CommandHandler(self._agent_com, self._aug_manager)
         self._output.set_agent_com(self._agent_com)
         self._agent_com.start()
